@@ -3,28 +3,28 @@ OC.L10N.register(
     {
     "Details" : "Detalios",
     "Rename" : "Renominar",
+    "Copy link" : "Copiar ligamine",
     "Move" : "Mover",
-    "Delete" : "Deler",
-    "Search" : "Cercar",
+    "Select all" : "Selectionar toto",
+    "Go back" : "Retornar",
     "New" : "Nove",
     "New folder" : "Nove dossier",
-    "Select all" : "Selectionar toto",
+    "Search" : "Cercar",
+    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers"],
+    "Rename folder" : "Renominar dossier",
     "Cancel" : "Cancellar",
     "Recent" : "Recente",
-    "Import" : "Importar",
-    "Export" : "Exportar",
-    "Alphabetically" : "Alphabeticamente",
+    "Shared with you" : "Compartite con te",
+    "Files" : "Files",
+    "Delete" : "Deler",
     "Title" : "Titulo",
     "Link" : "Ligamine",
     "Tags" : "Etiquettas",
-    "Attachments" : "Attachamentos",
     "Notes" : "Notas",
     "Owner" : "Owner",
     "Sharing" : "Compartente",
     "Share link" : "Compartir ligamine",
-    "Copy link" : "Copiar ligamine",
     "Allow editing" : "Permitter modificar",
-    "Select" : "Selectionar",
     "Folder" : "Dossier",
     "Save" : "Salveguardar"
 },
