@@ -168,6 +168,10 @@ OC.L10N.register(
     "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "書籤應用程式可以每天自動備份您的書籤，以防止跨裝置同步書籤時遺失資料。",
     "Enable backups" : "啟用備份",
     "Enter the path of a folder in your Files where backups will be stored." : "輸入在您「檔案」中要儲存備份的資料夾路徑。",
+    "Context Chat integration" : "情境聊天整合",
+    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "書籤應用程式可自動將書籤網站的文字內容提供給情境聊天，以便根據這些內容發問並獲得答案。只有啟用自動封存時才能使用此功能。",
+    "Context chat is currently not installed, but is required for this feature." : "目前尚未安裝情境聊天，但此功能需要情境聊天。",
+    "Enable Context Chat integration" : "啟用情境聊天整合",
     "Client apps" : "客戶端 apps",
     "Also check out the collection of client apps that integrate with this app: " : "還請檢查與此應用程序集成的客戶端應用程序的集合：",
     "Install web app" : "安裝 web 應用程式",
