@@ -1,4 +1,5 @@
 <?php
+
 /*
  * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
  *
@@ -38,7 +39,7 @@ class FileCacheGCJob extends TimedJob {
 		try {
 			$this->fileCache->gc();
 		} catch (NotPermittedException $e) {
-			$this->logger->error('Could not collect garbage: ' . $e->getMessage());
+			$this->logger->warning('Could not collect garbage: Missing permissions: ' . $e->getMessage());
 		}
 	}
 }
